CREATE TABLE koca_lcp_workflow_page_group (
	id BIGINT NOT NULL,
	tenant_id VARCHAR ( 32 ) DEFAULT '-1' NOT NULL COMMENT '租户id',
	group_code VARCHAR ( 64 ) NOT NULL COMMENT '页面分组编码',
	group_name VARCHAR ( 64 ) NOT NULL COMMENT '页面分组名称',
	parent_id BIGINT DEFAULT '-1' NOT NULL COMMENT '父级目录',
	id_path VARCHAR ( 512 ) NOT NULL COMMENT '页面分组id路径，用于删除或查询',
	sort_no INT DEFAULT 0 NOT NULL COMMENT '序号，用于同级目录排序',
	created_by VARCHAR ( 32 ) NOT NULL COMMENT '创建人',
	updated_by VARCHAR ( 32 ) NOT NULL COMMENT '更新人',
	created_at VARCHAR ( 32 ) NOT NULL COMMENT '创建时间',
	updated_at VARCHAR ( 32 ) NOT NULL COMMENT '更新时间',
CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE_GROUP PRIMARY KEY ( id )) COMMENT = '工作流表单分组';

ALTER TABLE koca_lcp_workflow_page_group COMMENT = '工作流表单分组';

CREATE UNIQUE INDEX uk_lcp_wf_page_group_code ON koca_lcp_workflow_page_group ( tenant_id, parent_id, group_code );

CREATE UNIQUE INDEX uk_lcp_wf_page_group_name ON koca_lcp_workflow_page_group ( tenant_id, parent_id, group_name );

CREATE TABLE koca_lcp_workflow_page (
	id BIGINT NOT NULL,
	tenant_id VARCHAR ( 32 ) DEFAULT '-1' NOT NULL COMMENT '租户id',
	group_id BIGINT DEFAULT '-1' NOT NULL COMMENT '父级目录',
	workflow_page_code VARCHAR ( 64 ) NOT NULL COMMENT '工作流表单编码',
	workflow_page_name VARCHAR ( 64 ) NOT NULL COMMENT '工作流表单名称',
	workflow_page_meta LONGTEXT NULL COMMENT '工作流表单元数据',
	workflow_page_type VARCHAR ( 32 ) DEFAULT 'FROM' NOT NULL COMMENT '类型:表单/模版',
	meta_comp_json LONGTEXT NULL COMMENT '元数据组件json',
	meta_item_json LONGTEXT NULL COMMENT '元数据表单项json',
	deploy_status VARCHAR ( 32 ) NOT NULL COMMENT '发布状态',
	created_by VARCHAR ( 32 ) NOT NULL COMMENT '创建人',
	updated_by VARCHAR ( 32 ) NOT NULL COMMENT '更新人',
	created_at VARCHAR ( 32 ) NOT NULL COMMENT '创建时间',
	updated_at VARCHAR ( 32 ) NOT NULL COMMENT '更新时间',
CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE PRIMARY KEY ( id )) COMMENT = '工作流表单';

ALTER TABLE koca_lcp_workflow_page COMMENT = '工作流表单';

CREATE UNIQUE INDEX uk_lcp_wf_page_code ON koca_lcp_workflow_page ( tenant_id, workflow_page_type, workflow_page_code );

CREATE UNIQUE INDEX uk_lcp_wf_page_name ON koca_lcp_workflow_page ( tenant_id, workflow_page_type, workflow_page_name );

CREATE TABLE koca_lcp_workflow_page_inst (
	id BIGINT NOT NULL,
	tenant_id VARCHAR ( 32 ) DEFAULT '-1' NOT NULL COMMENT '租户id',
	workflow_page_code VARCHAR ( 64 ) NOT NULL COMMENT '工作流表单CODE',
	workflow_page_meta LONGTEXT NULL COMMENT '工作流表单元数据',
	meta_comp_json LONGTEXT NULL COMMENT '元数据组件json',
	meta_item_json LONGTEXT NULL COMMENT '元数据表单项json',
	deploy_at VARCHAR ( 32 ) NOT NULL COMMENT '发布时间',
	deploy_version INT NOT NULL COMMENT '发布版本号',
CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE_INST PRIMARY KEY ( id )) COMMENT = '工作流表单实例表';

ALTER TABLE koca_lcp_workflow_page_inst COMMENT = '工作流表单实例表';

CREATE UNIQUE INDEX uk_lcp_wf_page_inst_code ON koca_lcp_workflow_page_inst(tenant_id, deploy_version, workflow_page_code);

CREATE TABLE koca_lcp_var_workflow_page (
	id BIGINT NOT NULL,
	workflow_page_id BIGINT NOT NULL COMMENT '工作流表单id',
	var_name VARCHAR ( 512 ) NOT NULL COMMENT '全局变量/方法名称',
CONSTRAINT PK_KOCA_LCP_VAR_WORKFLOW_PAGE PRIMARY KEY ( id )) COMMENT = '全局变量/方法-工作流表单映射表';

ALTER TABLE koca_lcp_var_workflow_page COMMENT = '全局变量/方法-工作流表单映射表';

CREATE UNIQUE INDEX uk_lcp_var_wf_page_id ON koca_lcp_var_workflow_page ( workflow_page_id, var_name );

CREATE TABLE koca_lcp_var_wf_page_inst (
	id BIGINT NOT NULL,
	var_name VARCHAR ( 512 ) NOT NULL COMMENT '全局变量/方法名称',
	var_type VARCHAR ( 16 ) NOT NULL COMMENT '类型：VAR、METHOD',
	var_content TEXT NOT NULL COMMENT '全局变量/方法内容',
	inst_id BIGINT NOT NULL COMMENT '实例id',
CONSTRAINT PK_KOCA_LCP_VAR_WF_PAGE_INST PRIMARY KEY ( id )) COMMENT = '全局变量/方法-页面映射实例表';

ALTER TABLE koca_lcp_var_wf_page_inst COMMENT = '全局变量/方法-页面映射实例表';

CREATE UNIQUE INDEX uk_lcp_wf_page_var_inst ON koca_lcp_var_wf_page_inst ( inst_id, var_name );

CREATE TABLE koca_lcp_workflow_page_tmpl (
	id BIGINT NOT NULL,
	tenant_id VARCHAR ( 32 ) DEFAULT '-1' NOT NULL COMMENT '租户id',
	tmpl_name VARCHAR ( 64 ) NOT NULL COMMENT '模版名称',
	workflow_page_meta LONGTEXT NULL COMMENT '工作流表单元数据',
	meta_comp_json LONGTEXT NULL COMMENT '元数据组件json',
	meta_item_json LONGTEXT NULL COMMENT '元数据表单项json',
	created_by VARCHAR ( 32 ) NOT NULL COMMENT '创建人',
	updated_by VARCHAR ( 32 ) NOT NULL COMMENT '更新人',
	created_at VARCHAR ( 32 ) NOT NULL COMMENT '创建时间',
	updated_at VARCHAR ( 32 ) NOT NULL COMMENT '更新时间',
CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE_TMPL PRIMARY KEY ( id )) COMMENT = '工作流表单模版表';

ALTER TABLE koca_lcp_workflow_page_tmpl COMMENT = '工作流表单模版表';

CREATE TABLE koca_lcp_var_wf_page_tmpl (
	id BIGINT NOT NULL,
	var_name VARCHAR ( 512 ) NOT NULL COMMENT '全局变量/方法名称',
	tmpl_id BIGINT NOT NULL COMMENT '模版id',
CONSTRAINT PK_KOCA_LCP_VAR_WF_PAGE_TMPL PRIMARY KEY ( id )) COMMENT = '全局变量/方法-页面映射模版表';

ALTER TABLE koca_lcp_var_wf_page_tmpl COMMENT = '全局变量/方法-页面映射模版表';

CREATE UNIQUE INDEX uk_lcp_wf_page_tmpl_var ON koca_lcp_var_wf_page_tmpl ( tmpl_id, var_name );
