﻿-- 
--  creating table sys_dictionary
--  =============================
-- 
create table sys_dictionary
(
  dict_code     varchar2(32) not null,
  dict_name     varchar2(128),
  dict_type     varchar2(2),
  maintain_flag varchar2(16),
  remark        varchar2(128 char)
)
;
alter table sys_dictionary
  add primary key (dict_code);

-- 
--  creating table sys_dictionary_i18n
--  ==================================
-- 
create table sys_dictionary_i18n
(
  dict_code     varchar2(32) not null,
  language_type varchar2(32) not null,
  dict_name     varchar2(256 char)
)
;
comment on table sys_dictionary_i18n
  is '字典国际化表';
comment on column sys_dictionary_i18n.dict_code
  is '字典编码';
comment on column sys_dictionary_i18n.language_type
  is '语言类型';
comment on column sys_dictionary_i18n.dict_name
  is '字典名称';
alter table sys_dictionary_i18n
  add unique (dict_code, language_type);

-- 
--  creating table sys_dictionary_item
--  ==================================
-- 
create table sys_dictionary_item
(
  dict_code      varchar2(32) not null,
  org_code       varchar2(8) not null,
  dict_item      varchar2(32) not null,
  dict_item_name varchar2(128),
  dict_ord       number,
  remark         varchar2(128 char)
)
;
alter table sys_dictionary_item
  add primary key (dict_code, org_code, dict_item);

-- 
--  creating table sys_dictionary_item_i18n
--  =======================================
-- 
create table sys_dictionary_item_i18n
(
  dict_code      varchar2(32) not null,
  org_code       varchar2(8) not null,
  dict_item      varchar2(32) not null,
  dict_item_name varchar2(128 char),
  language_type  varchar2(32) not null
)
;
comment on table sys_dictionary_item_i18n
  is '字典项国际化';
comment on column sys_dictionary_item_i18n.dict_code
  is '字典编码';
comment on column sys_dictionary_item_i18n.org_code
  is '机构编码';
comment on column sys_dictionary_item_i18n.dict_item
  is '字典项';
comment on column sys_dictionary_item_i18n.dict_item_name
  is '字典项名称';
comment on column sys_dictionary_item_i18n.language_type
  is '语言类型';
alter table sys_dictionary_item_i18n
  add unique (dict_code, org_code, dict_item, language_type);

-- 
--  creating table sys_menu
--  =======================
-- 
create table sys_menu
(
  menu_id     varchar2(10) not null,
  menu_status varchar2(2),
  menu_type   varchar2(2),
  menu_name   varchar2(64),
  menu_url    varchar2(256),
  parent_menu varchar2(10),
  prev_menu   varchar2(10),
  menu_icon   varchar2(32),
  load_type   varchar2(2),
  remark      varchar2(64 char)
)
;
comment on column sys_menu.menu_id
  is '菜单编号';
comment on column sys_menu.menu_status
  is '菜单状态';
comment on column sys_menu.menu_type
  is '菜单类型';
comment on column sys_menu.menu_name
  is '菜单名称';
comment on column sys_menu.menu_url
  is '菜单链接';
comment on column sys_menu.parent_menu
  is '父菜单';
comment on column sys_menu.prev_menu
  is '同级前菜单';
comment on column sys_menu.menu_icon
  is '菜单图标';
comment on column sys_menu.load_type
  is '加载类型';
comment on column sys_menu.remark
  is '备注信息';
alter table sys_menu
  add primary key (menu_id);

-- 
--  creating table sys_menu_i18n
--  ============================
-- 
create table sys_menu_i18n
(
  menu_id       varchar2(10) not null,
  menu_name     varchar2(64 char),
  language_type varchar2(32) not null
)
;
comment on table sys_menu_i18n
  is '菜单国际化表';
comment on column sys_menu_i18n.menu_id
  is '菜单id';
comment on column sys_menu_i18n.menu_name
  is '菜单名称';
comment on column sys_menu_i18n.language_type
  is '语言类型';
alter table sys_menu_i18n
   add unique (menu_id, language_type);

-- 
--  creating table sys_parameter
--  ============================
-- 
create table sys_parameter
(
  par_code      varchar2(32) not null,
  par_name      varchar2(256 char),
  par_type      varchar2(2),
  par_type_sub  varchar2(2),
  maintain_flag varchar2(2),
  remark        varchar2(128 char)
)
;
alter table sys_parameter
  add primary key (par_code);

-- 
--  creating table sys_parameter_i18n
--  =================================
-- 
create table sys_parameter_i18n
(
  par_code      varchar2(32) not null,
  language_type varchar2(32) not null,
  par_name      varchar2(256 char)
)
;
comment on table sys_parameter_i18n
  is '参数国际化表';
comment on column sys_parameter_i18n.par_code
  is '参数编码';
comment on column sys_parameter_i18n.language_type
  is '语言类型';
comment on column sys_parameter_i18n.par_name
  is '参数名称';
alter table sys_parameter_i18n
  add unique (par_code, language_type);

-- 
--  creating table sys_parameter_val
--  ================================
-- 
create table sys_parameter_val
(
  par_code varchar2(32) not null,
  org_code varchar2(8) not null,
  par_val  varchar2(256)
)
;
alter table sys_parameter_val
  add primary key (par_code, org_code);

-- 
--  creating table sys_parameter_val_i18n
--  =====================================
-- 
create table sys_parameter_val_i18n
(
  par_code      varchar2(32) not null,
  org_code      varchar2(8) not null,
  language_type varchar2(32) not null,
  par_val       varchar2(256 char)
)
;
comment on table sys_parameter_val_i18n
  is '参数值国际化表';
comment on column sys_parameter_val_i18n.par_code
  is '参数编码';
comment on column sys_parameter_val_i18n.org_code
  is '机构编码';
comment on column sys_parameter_val_i18n.language_type
  is '语言类型';
comment on column sys_parameter_val_i18n.par_val
  is '参数值';
alter table sys_parameter_val_i18n
  add unique (par_code, org_code, language_type);
