﻿-- 
--  creating table koca_org_info_base
--  ============================
-- 
create table koca_org_info_base
(
    org_code      varchar2(8) not null,
    org_status    varchar2(2),
    org_type      varchar2(8),
    parent_org    varchar2(8),
    org_name      varchar2(32 char),
    org_full_name varchar2(64 char),
    address       varchar2(64 char),
    zip_code      varchar2(6),
    tel           varchar2(16),
    remark        varchar2(128 char)
)
;
comment on column koca_org_info_base.org_code
    is '机构代码';
comment on column koca_org_info_base.org_status
    is '机构状态，字典，org_status';
comment on column koca_org_info_base.org_type
    is '机构类型，字典，org_type';
comment on column koca_org_info_base.parent_org
    is '上级机构';
comment on column koca_org_info_base.org_name
    is '机构名称';
comment on column koca_org_info_base.org_full_name
    is '机构全称';
comment on column koca_org_info_base.address
    is '机构地址';
comment on column koca_org_info_base.zip_code
    is '机构邮编';
comment on column koca_org_info_base.tel
    is '机构电话';
comment on column koca_org_info_base.remark
    is '备注信息';
alter table koca_org_info_base
    add primary key (org_code);

-- 
--  creating table koca_org_info_ext
--  ===========================
-- 
create table koca_org_info_ext
(
    org_code  varchar2(8) not null,
    org_key   varchar2(16),
    org_value varchar2(128)
)
;
comment on column koca_org_info_ext.org_code
    is '机构代码，主键';
comment on column koca_org_info_ext.org_key
    is '信息key，字典，org_key';
comment on column koca_org_info_ext.org_value
    is '信息value';
alter table koca_org_info_ext
    add constraint org_info_ext_key primary key (org_code);

-- 
--  creating table koca_role_info
--  ========================
-- 
create table koca_role_info
(
    role_no     varchar2(8) not null,
    role_name   varchar2(32 char),
    role_type   varchar2(2),
    role_status varchar2(2),
    remark      varchar2(128 char),
    tenant_id   varchar2(32) default '*',
    modifiable   varchar2(2) default '1'
)
;
comment on table koca_role_info
    is '角色信息表';
comment on column koca_role_info.role_no
    is '角色编号';
comment on column koca_role_info.role_name
    is '角色名称';
comment on column koca_role_info.role_type
    is '角色类型';
comment on column koca_role_info.role_status
    is '角色状态';
comment on column koca_role_info.remark
    is '描述';
comment on column koca_role_info.tenant_id
    is '租户id';
alter table koca_role_info
    add primary key (role_no, tenant_id);

-- 
--  creating table koca_user_info_base
--  =============================
-- 
create table koca_user_info_base
(
    user_no       varchar2(32)      not null,
    user_type     varchar2(2)       not null,
    user_status   varchar2(2)       not null,
    user_code     varchar2(32)      not null,
    user_name     varchar2(32 char) not null,
    id_type       varchar2(2)       not null,
    id_code       varchar2(32)      not null,
    id_iss_agcy   varchar2(64 char),
    id_address    varchar2(128 char),
    id_begin_date varchar2(8),
    id_exp_date   varchar2(8),
    birthday      varchar2(8),
    sex           varchar2(2),
    nationality   varchar2(2),
    citizenship   varchar2(3),
    education     varchar2(2),
    native_place  varchar2(32 char),
    mobile_tel    varchar2(11),
    email         varchar2(32),
    address       varchar2(128 char),
    zip_code      varchar2(6 char),
    user_icon     varchar2(255),
    create_date   varchar2(8),
    cancel_date   varchar2(32),
    remark        varchar2(128 char),
    oper_ext_attr varchar2(16) default '0'
)
;
comment on column koca_user_info_base.user_no
    is '人员编号';
comment on column koca_user_info_base.user_type
    is '人员类型，字典user_type';
comment on column koca_user_info_base.user_status
    is '人员状态,字典user_status';
comment on column koca_user_info_base.user_code
    is '人员代码';
comment on column koca_user_info_base.user_name
    is '姓名';
comment on column koca_user_info_base.id_type
    is '证件类型';
comment on column koca_user_info_base.id_code
    is '证件号码';
comment on column koca_user_info_base.id_iss_agcy
    is '发证机关';
comment on column koca_user_info_base.id_address
    is '证件地址';
comment on column koca_user_info_base.id_begin_date
    is '证件开始日期';
comment on column koca_user_info_base.id_exp_date
    is '证件结束日期';
comment on column koca_user_info_base.birthday
    is '出生日期';
comment on column koca_user_info_base.sex
    is '性别,字典，sex';
comment on column koca_user_info_base.nationality
    is '民族,字典';
comment on column koca_user_info_base.citizenship
    is '国籍,字典';
comment on column koca_user_info_base.education
    is '学历，字典';
comment on column koca_user_info_base.native_place
    is '籍贯';
comment on column koca_user_info_base.mobile_tel
    is '手机号码';
comment on column koca_user_info_base.email
    is '邮箱';
comment on column koca_user_info_base.address
    is '联系地址';
comment on column koca_user_info_base.zip_code
    is '邮政编码';
comment on column koca_user_info_base.user_icon
    is '用户头像';
comment on column koca_user_info_base.create_date
    is '注册日期';
comment on column koca_user_info_base.cancel_date
    is '注销日期';
comment on column koca_user_info_base.remark
    is '备注信息';
alter table koca_user_info_base
    add primary key (user_no);

-- 
--  creating table koca_user_info_ext
--  ============================
-- 
create table koca_user_info_ext
(
    user_no    varchar2(32) not null,
    user_key   varchar2(16) not null,
    user_value varchar2(128)
)
;
comment on column koca_user_info_ext.user_no
    is '人员编号';
comment on column koca_user_info_ext.user_key
    is '信息key，字典user_key';
comment on column koca_user_info_ext.user_value
    is '信息value';
alter table koca_user_info_ext
    add constraint user_info_ext_key primary key (user_no, user_key);

-- 
--  creating table koca_user_opt_log
--  ===========================
-- 
create table koca_user_opt_log
(
    s_no        number not null,
    begin_time  date,
    end_time    date,
    user_no     varchar2(32),
    opt_code    varchar2(64),
    opt_data    clob,
    res_status  varchar2(8),
    res_message varchar2(128),
    res_code    varchar2(8),
    remark      varchar2(128)
)
;
comment on column koca_user_opt_log.s_no
    is '自增';
alter table koca_user_opt_log
    add primary key (s_no);

-- 
--  creating table koca_user_org_info
--  ============================
-- 
create table koca_user_org_info
(
    org_code varchar2(8)  not null,
    user_no  varchar2(32) not null
)
;
comment on column koca_user_org_info.org_code
    is '机构代码，主键';
alter table koca_user_org_info
    add constraint user_koca_org_info_key primary key (user_no);

-- 
--  creating table koca_user_pwd
--  =======================
-- 
create table koca_user_pwd
(
    user_no     varchar2(32) not null,
    pwd         varchar2(64),
    pwd_status  varchar2(2),
    update_time date,
    remark      varchar2(128),
    wrong_time  number(8) default 0
)
;
alter table koca_user_pwd
    add primary key (user_no);

-- 
--  creating table koca_user_pwd_log
--  ===========================
-- 
create table koca_user_pwd_log
(
    sno           number(11) not null,
    user_no       varchar2(32),
    pwd           varchar2(64),
    modified_oper varchar2(64),
    set_date      date
)
;
alter table koca_user_pwd_log
    add primary key (sno);

-- 
--  creating table user_koca_role_info
--  =============================
-- 
create table koca_user_role_info
(
    user_no varchar2(32) not null,
    role_no varchar2(8)  not null,
    tenant_id varchar2(32)  default '*' not null
)
;
comment on table koca_user_role_info
    is '人员角色信息表';
comment on column koca_user_role_info.user_no
    is '人员编号';
comment on column koca_user_role_info.role_no
    is '角色编号';
comment on column koca_user_role_info.tenant_id
    is '租户id';
alter table koca_user_role_info
    add constraint user_role_key primary key (user_no, role_no, tenant_id);

-- 
--  creating table koca_menu_api
--  =============================
-- 
create table koca_menu_api
(
    menu_id      varchar2(10)  not null,
    api_code     varchar2(100) not null,
    resource_url varchar2(255)
)
;
comment on table koca_menu_api
    is '菜单api信息表';
comment on column koca_menu_api.menu_id
    is '菜单编号';
comment on column koca_menu_api.api_code
    is 'api接口代码';
comment on column koca_menu_api.resource_url
    is '请求resource路径';
alter table koca_menu_api
    add constraint menu_api_key primary key (api_code);

create table koca_sys_password_parameter
(
    par_code varchar2(32) not null,
    par_name varchar2(128 char),
    par_val  varchar2(32),
    remark   varchar2(128 char)
);
alter table koca_sys_password_parameter
    add primary key (par_code);

-- 
--  creating sequence user_opt_log_no
--  =================================
-- 
create sequence user_opt_log_no
    minvalue 1
    maxvalue 99999999999
    start with 1
    increment by 1
    nocache;

-- 
--  creating sequence user_pwd_log_no
--  =================================
-- 
create sequence user_pwd_log_no
    minvalue 1
    maxvalue 99999999999
    start with 92
    increment by 1
    nocache;
