CREATE TABLE koca_lcp_workflow_page_group (id NUMBER(38, 0) NOT NULL, tenant_id NVARCHAR2(32) DEFAULT '-1' NOT NULL, group_code NVARCHAR2(64) NOT NULL, group_name NVARCHAR2(64) NOT NULL, parent_id NUMBER(38, 0) DEFAULT '-1' NOT NULL, id_path NVARCHAR2(512) NOT NULL, sort_no INTEGER DEFAULT 0 NOT NULL, created_by NVARCHAR2(32) NOT NULL, updated_by NVARCHAR2(32) NOT NULL, created_at NVARCHAR2(32) NOT NULL, updated_at NVARCHAR2(32) NOT NULL, CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE_GROU PRIMARY KEY (id));

COMMENT ON TABLE koca_lcp_workflow_page_group IS '工作流表单分组';

COMMENT ON COLUMN koca_lcp_workflow_page_group.id IS '主键ID';

COMMENT ON COLUMN koca_lcp_workflow_page_group.tenant_id IS '租户id';

COMMENT ON COLUMN koca_lcp_workflow_page_group.group_code IS '页面分组编码';

COMMENT ON COLUMN koca_lcp_workflow_page_group.group_name IS '页面分组名称';

COMMENT ON COLUMN koca_lcp_workflow_page_group.parent_id IS '父级目录';

COMMENT ON COLUMN koca_lcp_workflow_page_group.id_path IS '页面分组id路径，用于删除或查询';

COMMENT ON COLUMN koca_lcp_workflow_page_group.sort_no IS '序号，用于同级目录排序';

COMMENT ON COLUMN koca_lcp_workflow_page_group.created_by IS '创建人';

COMMENT ON COLUMN koca_lcp_workflow_page_group.updated_by IS '更新人';

COMMENT ON COLUMN koca_lcp_workflow_page_group.created_at IS '创建时间';

COMMENT ON COLUMN koca_lcp_workflow_page_group.updated_at IS '更新时间';

CREATE UNIQUE INDEX uk_lcp_wf_page_group_code ON koca_lcp_workflow_page_group(tenant_id, parent_id, group_code);

CREATE UNIQUE INDEX uk_lcp_wf_page_group_name ON koca_lcp_workflow_page_group(tenant_id, parent_id, group_name);

CREATE TABLE koca_lcp_workflow_page (id NUMBER(38, 0) NOT NULL, tenant_id NVARCHAR2(32) DEFAULT '-1' NOT NULL, group_id NUMBER(38, 0) DEFAULT '-1' NOT NULL, workflow_page_code NVARCHAR2(64) NOT NULL, workflow_page_name NVARCHAR2(64) NOT NULL, workflow_page_meta CLOB, workflow_page_type NVARCHAR2(32) DEFAULT 'FROM' NOT NULL, meta_comp_json CLOB, meta_item_json CLOB, deploy_status NVARCHAR2(32) NOT NULL, created_by NVARCHAR2(32) NOT NULL, updated_by NVARCHAR2(32) NOT NULL, created_at NVARCHAR2(32) NOT NULL, updated_at NVARCHAR2(32) NOT NULL, CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE PRIMARY KEY (id));

COMMENT ON TABLE koca_lcp_workflow_page IS '工作流表单';

COMMENT ON COLUMN koca_lcp_workflow_page.id IS '主键ID';

COMMENT ON COLUMN koca_lcp_workflow_page.tenant_id IS '租户id';

COMMENT ON COLUMN koca_lcp_workflow_page.group_id IS '父级目录';

COMMENT ON COLUMN koca_lcp_workflow_page.workflow_page_code IS '工作流表单编码';

COMMENT ON COLUMN koca_lcp_workflow_page.workflow_page_name IS '工作流表单名称';

COMMENT ON COLUMN koca_lcp_workflow_page.workflow_page_meta IS '工作流表单元数据';

COMMENT ON COLUMN koca_lcp_workflow_page.workflow_page_type IS '类型:表单/模版';

COMMENT ON COLUMN koca_lcp_workflow_page.meta_comp_json IS '元数据组件json';

COMMENT ON COLUMN koca_lcp_workflow_page.meta_item_json IS '元数据表单项json';

COMMENT ON COLUMN koca_lcp_workflow_page.deploy_status IS '发布状态';

COMMENT ON COLUMN koca_lcp_workflow_page.created_by IS '创建人';

COMMENT ON COLUMN koca_lcp_workflow_page.updated_by IS '更新人';

COMMENT ON COLUMN koca_lcp_workflow_page.created_at IS '创建时间';

COMMENT ON COLUMN koca_lcp_workflow_page.updated_at IS '更新时间';

CREATE UNIQUE INDEX uk_lcp_wf_page_code ON koca_lcp_workflow_page(tenant_id, workflow_page_type, workflow_page_code);

CREATE UNIQUE INDEX uk_lcp_wf_page_name ON koca_lcp_workflow_page(tenant_id, workflow_page_type, workflow_page_name);

CREATE TABLE koca_lcp_workflow_page_inst (id NUMBER(38, 0) NOT NULL, tenant_id NVARCHAR2(32) DEFAULT '-1' NOT NULL, workflow_page_code NVARCHAR2(64) NOT NULL, workflow_page_meta CLOB, meta_comp_json CLOB, meta_item_json CLOB, deploy_at NVARCHAR2(32) NOT NULL, deploy_version INTEGER NOT NULL, CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE_INST PRIMARY KEY (id));

COMMENT ON TABLE koca_lcp_workflow_page_inst IS '工作流表单实例表';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.id IS '主键ID';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.tenant_id IS '租户id';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.workflow_page_code IS '工作流表单CODE';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.workflow_page_meta IS '工作流表单元数据';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.meta_comp_json IS '元数据组件json';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.meta_item_json IS '元数据表单项json';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.deploy_at IS '发布时间';

COMMENT ON COLUMN koca_lcp_workflow_page_inst.deploy_version IS '发布版本号';

CREATE UNIQUE INDEX uk_lcp_wf_page_inst_code ON koca_lcp_workflow_page_inst(tenant_id, deploy_version, workflow_page_code);

CREATE TABLE koca_lcp_var_workflow_page (id NUMBER(38, 0) NOT NULL, workflow_page_id NUMBER(38, 0) NOT NULL, var_name NVARCHAR2(512) NOT NULL, CONSTRAINT PK_KOCA_LCP_VAR_WORKFLOW_PAGE PRIMARY KEY (id));

COMMENT ON TABLE koca_lcp_var_workflow_page IS '全局变量/方法-工作流表单映射表';

COMMENT ON COLUMN koca_lcp_var_workflow_page.id IS '主键ID';

COMMENT ON COLUMN koca_lcp_var_workflow_page.workflow_page_id IS '工作流表单id';

COMMENT ON COLUMN koca_lcp_var_workflow_page.var_name IS '全局变量/方法名称';

CREATE UNIQUE INDEX uk_lcp_var_wf_page_id ON koca_lcp_var_workflow_page(workflow_page_id, var_name);

CREATE TABLE koca_lcp_var_wf_page_inst (id NUMBER(38, 0) NOT NULL, var_name NVARCHAR2(512) NOT NULL, var_type NVARCHAR2(16) NOT NULL, var_content CLOB NOT NULL, inst_id NUMBER(38, 0) NOT NULL, CONSTRAINT PK_KOCA_LCP_VAR_WF_PAGE_INST PRIMARY KEY (id));

COMMENT ON TABLE koca_lcp_var_wf_page_inst IS '全局变量/方法-页面映射实例表';

COMMENT ON COLUMN koca_lcp_var_wf_page_inst.id IS '主键ID';

COMMENT ON COLUMN koca_lcp_var_wf_page_inst.var_name IS '全局变量/方法名称';

COMMENT ON COLUMN koca_lcp_var_wf_page_inst.var_type IS '类型：VAR、METHOD';

COMMENT ON COLUMN koca_lcp_var_wf_page_inst.var_content IS '全局变量/方法内容';

COMMENT ON COLUMN koca_lcp_var_wf_page_inst.inst_id IS '实例id';

CREATE UNIQUE INDEX uk_lcp_wf_page_var_inst ON koca_lcp_var_wf_page_inst(inst_id, var_name);

CREATE TABLE koca_lcp_workflow_page_tmpl (id NUMBER(38, 0) NOT NULL, tenant_id NVARCHAR2(32) DEFAULT '-1' NOT NULL, tmpl_name NVARCHAR2(64) NOT NULL, workflow_page_meta CLOB, meta_comp_json CLOB, meta_item_json CLOB, created_by NVARCHAR2(32) NOT NULL, updated_by NVARCHAR2(32) NOT NULL, created_at NVARCHAR2(32) NOT NULL, updated_at NVARCHAR2(32) NOT NULL, CONSTRAINT PK_KOCA_LCP_WORKFLOW_PAGE_TMPL PRIMARY KEY (id));

COMMENT ON TABLE koca_lcp_workflow_page_tmpl IS '工作流表单模版表';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.id IS '主键ID';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.tenant_id IS '租户id';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.tmpl_name IS '模版名称';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.workflow_page_meta IS '工作流表单元数据';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.meta_comp_json IS '元数据组件json';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.meta_item_json IS '元数据表单项json';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.created_by IS '创建人';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.updated_by IS '更新人';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.created_at IS '创建时间';

COMMENT ON COLUMN koca_lcp_workflow_page_tmpl.updated_at IS '更新时间';

CREATE TABLE koca_lcp_var_wf_page_tmpl (id NUMBER(38, 0) NOT NULL, var_name NVARCHAR2(512) NOT NULL, tmpl_id NUMBER(38, 0) NOT NULL, CONSTRAINT PK_KOCA_LCP_VAR_WF_PAGE_TMPL PRIMARY KEY (id));

COMMENT ON TABLE koca_lcp_var_wf_page_tmpl IS '全局变量/方法-页面映射模版表';

COMMENT ON COLUMN koca_lcp_var_wf_page_tmpl.id IS '主键ID';

COMMENT ON COLUMN koca_lcp_var_wf_page_tmpl.var_name IS '全局变量/方法名称';

COMMENT ON COLUMN koca_lcp_var_wf_page_tmpl.tmpl_id IS '模版id';

CREATE UNIQUE INDEX uk_lcp_wf_page_tmpl_var ON koca_lcp_var_wf_page_tmpl(tmpl_id, var_name);

