
CREATE TABLE rpt_pb_api_config  (
  DATA_SET_ID NUMBER(20,0) NOT NULL,
  REQUEST_PATH varchar(256) NOT NULL ,
  REQUEST_METHOD varchar(8) NOT NULL,
  API_SOURCE varchar(8) NOT NULL,
  POST_DATA_CONTENT_TYPE varchar(8) NOT NULL,
  HEADER_PARAM CLOB NULL,
  POST_DATA_CONTENT_PARAM CLOB NULL,
  data_json_path varchar(128) NULL,
  DATAID NUMBER(20,0) NULL,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (DATA_SET_ID)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_api_config IS 'API配置表';
COMMENT ON COLUMN rpt_pb_api_config.DATA_SET_ID IS '数据集编号';
COMMENT ON COLUMN rpt_pb_api_config.REQUEST_PATH IS '请求路径';
COMMENT ON COLUMN rpt_pb_api_config.REQUEST_METHOD IS '请求方法';
COMMENT ON COLUMN rpt_pb_api_config.API_SOURCE IS 'API来源';
COMMENT ON COLUMN rpt_pb_api_config.POST_DATA_CONTENT_TYPE IS 'POST数据内容方式';
COMMENT ON COLUMN rpt_pb_api_config.HEADER_PARAM IS 'HEADER参数';
COMMENT ON COLUMN rpt_pb_api_config.POST_DATA_CONTENT_PARAM IS 'POST数据内容参数';
COMMENT ON COLUMN rpt_pb_api_config.data_json_path IS '取值jsonPath';
COMMENT ON COLUMN rpt_pb_api_config.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_api_config.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_api_config.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_api_config.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_api_config.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_component_define  (
  COMPONENT_ID NUMBER(20,0) NOT NULL,
  COMPONENT_NAME varchar(64) NOT NULL,
  COMPONENT_TYPE varchar(8) NOT NULL,
  COMPONENT_CODE varchar(64) NOT NULL,
  PARENT_TYPE_ID varchar(8) NOT NULL,
  IMG_ADDR varchar(256) NULL ,
  EXAMPLE_DATA CLOB NOT NULL,
  STATUS varchar(8) NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (COMPONENT_ID)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_component_define IS '组件定义表';
COMMENT ON COLUMN rpt_pb_component_define.COMPONENT_ID IS '组件编号';
COMMENT ON COLUMN rpt_pb_component_define.COMPONENT_NAME IS '组件名称';
COMMENT ON COLUMN rpt_pb_component_define.COMPONENT_TYPE IS '组件类型';
COMMENT ON COLUMN rpt_pb_component_define.COMPONENT_CODE IS '组件编码';
COMMENT ON COLUMN rpt_pb_component_define.PARENT_TYPE_ID IS '父类型编号';
COMMENT ON COLUMN rpt_pb_component_define.IMG_ADDR IS '图标地址';
COMMENT ON COLUMN rpt_pb_component_define.EXAMPLE_DATA IS '示例数据';
COMMENT ON COLUMN rpt_pb_component_define.STATUS IS '启用状态';
COMMENT ON COLUMN rpt_pb_component_define.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_component_define.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_component_define.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_component_define.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_component_define.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_data_filter  (
  ID NUMBER(20,0) NOT NULL,
  DATA_SET_ID NUMBER(20,0) NOT NULL,
  NODE_ID NUMBER(20,0) NOT NULL ,
  PARENT_NODE_ID NUMBER(20,0) NOT NULL,
  FILTER_TYPE varchar(8) NOT NULL,
  NODE_CALC_TYPE varchar(8) NOT NULL,
  table_name varchar(64) NULL ,
  FIELD_NAME varchar(256) NULL ,
  value_type varchar(8) NULL ,
  SQL_OPERT varchar(8) NULL ,
  CMP_CONTENT varchar(1024) NULL ,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (ID)
)
NOCOMPRESS
NOPARALLEL ;
CREATE UNIQUE INDEX PB_DATA_FILTER_INDEX ON rpt_pb_data_filter (DATA_SET_ID, NODE_ID);
COMMENT ON TABLE rpt_pb_data_filter IS '数据过滤器表';
COMMENT ON COLUMN rpt_pb_data_filter.ID IS 'ID';
COMMENT ON COLUMN rpt_pb_data_filter.DATA_SET_ID IS '数据集编号';
COMMENT ON COLUMN rpt_pb_data_filter.NODE_ID IS '节点编号';
COMMENT ON COLUMN rpt_pb_data_filter.PARENT_NODE_ID IS '父节点编号';
COMMENT ON COLUMN rpt_pb_data_filter.FILTER_TYPE IS '过滤类型';
COMMENT ON COLUMN rpt_pb_data_filter.NODE_CALC_TYPE IS '节点运算类型';
COMMENT ON COLUMN rpt_pb_data_filter.table_name IS '表名称表名称';
COMMENT ON COLUMN rpt_pb_data_filter.FIELD_NAME IS '字段名称';
COMMENT ON COLUMN rpt_pb_data_filter.value_type IS '比值类型';
COMMENT ON COLUMN rpt_pb_data_filter.SQL_OPERT IS 'SQL运算符';
COMMENT ON COLUMN rpt_pb_data_filter.CMP_CONTENT IS '比较内容';
COMMENT ON COLUMN rpt_pb_data_filter.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_data_filter.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_data_filter.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_data_filter.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_data_filter.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_data_set  (
  DATA_SET_ID NUMBER(20,0) NOT NULL,
  DATA_SRC_ID NUMBER(20,0) NULL ,
  DATA_SET_NAME varchar(256) NOT NULL,
  DATA_SET_CLASS_ID NUMBER(20,0) NOT NULL,
  DATA_SET_TYPE varchar(8) NOT NULL,
  EXE_SQL CLOB NULL,
  JSON_CONTENT CLOB NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (DATA_SET_ID)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_data_set IS '数据集表';
COMMENT ON COLUMN rpt_pb_data_set.DATA_SET_ID IS '数据集编号';
COMMENT ON COLUMN rpt_pb_data_set.DATA_SRC_ID IS '数据源编号';
COMMENT ON COLUMN rpt_pb_data_set.DATA_SET_NAME IS '数据集名称';
COMMENT ON COLUMN rpt_pb_data_set.DATA_SET_CLASS_ID IS '分类编号';
COMMENT ON COLUMN rpt_pb_data_set.DATA_SET_TYPE IS '数据集类型';
COMMENT ON COLUMN rpt_pb_data_set.EXE_SQL IS '执行SQL';
COMMENT ON COLUMN rpt_pb_data_set.JSON_CONTENT IS 'JSON内容';
COMMENT ON COLUMN rpt_pb_data_set.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_data_set.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_data_set.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_data_set.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_data_set.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_data_set_class  (
  CLASS_ID NUMBER(20,0) NOT NULL,
  PARENT_CLASS_ID NUMBER(20,0) NOT NULL,
  CLASS_NAME varchar(256) NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (CLASS_ID)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_data_set_class IS '数据集分类定义表';
COMMENT ON COLUMN rpt_pb_data_set_class.CLASS_ID IS '分类编号';
COMMENT ON COLUMN rpt_pb_data_set_class.PARENT_CLASS_ID IS '父类编号';
COMMENT ON COLUMN rpt_pb_data_set_class.CLASS_NAME IS '分类名称';
COMMENT ON COLUMN rpt_pb_data_set_class.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_data_set_class.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_data_set_class.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_data_set_class.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_data_set_class.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_data_set_element  (
  ID NUMBER(20,0) NOT NULL,
  DATA_SET_ID NUMBER(20,0) NOT NULL,
  ORI_FIELD_NAME varchar(256) NOT NULL,
  SHOW_NAME varchar(256) NOT NULL,
  DATA_TYPE varchar(8) NOT NULL,
  TABLE_NAME varchar(64) NULL ,
  FIELD_PROP varchar(8) NOT NULL,
  ELEMENT_TYPE varchar(8) NOT NULL,
  EXPR_TYPE varchar(8) NULL ,
  HIDDEN_FLAG varchar(8) NOT NULL,
  DICTITEM NUMBER(20,0) NULL ,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (ID)
)
NOCOMPRESS
NOPARALLEL ;
CREATE UNIQUE INDEX PB_DATA_SET_ELEMENT_INDEX ON rpt_pb_data_set_element (DATA_SET_ID, ORI_FIELD_NAME, TABLE_NAME, ELEMENT_TYPE, EXPR_TYPE);
COMMENT ON TABLE rpt_pb_data_set_element IS '数据集元素表';
COMMENT ON COLUMN rpt_pb_data_set_element.ID IS 'ID';
COMMENT ON COLUMN rpt_pb_data_set_element.DATA_SET_ID IS '数据集编号';
COMMENT ON COLUMN rpt_pb_data_set_element.ORI_FIELD_NAME IS '原字段名称';
COMMENT ON COLUMN rpt_pb_data_set_element.SHOW_NAME IS '展示名称';
COMMENT ON COLUMN rpt_pb_data_set_element.DATA_TYPE IS '数据类型';
COMMENT ON COLUMN rpt_pb_data_set_element.TABLE_NAME IS '表名称';
COMMENT ON COLUMN rpt_pb_data_set_element.FIELD_PROP IS '字段属性字段属性';
COMMENT ON COLUMN rpt_pb_data_set_element.ELEMENT_TYPE IS '元素类型';
COMMENT ON COLUMN rpt_pb_data_set_element.EXPR_TYPE IS '函数类型';
COMMENT ON COLUMN rpt_pb_data_set_element.HIDDEN_FLAG IS '隐藏标志';
COMMENT ON COLUMN rpt_pb_data_set_element.DICTITEM IS '字典项';
COMMENT ON COLUMN rpt_pb_data_set_element.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_data_set_element.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_data_set_element.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_data_set_element.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_data_set_element.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_dict_index  (
  DICTITEM NUMBER(20,0) NOT NULL,
  ITEM_NAME varchar(128) NOT NULL,
  DISP_FLAG varchar(8) NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (DICTITEM)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_dict_index IS '数据映射字典表';
COMMENT ON COLUMN rpt_pb_dict_index.DICTITEM IS '字典项';
COMMENT ON COLUMN rpt_pb_dict_index.ITEM_NAME IS '字典名称';
COMMENT ON COLUMN rpt_pb_dict_index.DISP_FLAG IS '是否显示';
COMMENT ON COLUMN rpt_pb_dict_index.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_dict_index.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_dict_index.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_dict_index.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_dict_index.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_dict_value  (
  ID NUMBER(20,0) NOT NULL,
  DICTITEM NUMBER(20,0) NOT NULL,
  SUB_ITEM_NAME varchar(128) NOT NULL,
  SUB_ITEM varchar(8) NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (ID)
)
NOCOMPRESS
NOPARALLEL ;
CREATE UNIQUE INDEX PB_DICT_VALUE_INDEX ON rpt_pb_dict_value (DICTITEM, SUB_ITEM);
COMMENT ON TABLE rpt_pb_dict_value IS '数据映射字典项表';
COMMENT ON COLUMN rpt_pb_dict_value.ID IS 'ID';
COMMENT ON COLUMN rpt_pb_dict_value.DICTITEM IS '字典项';
COMMENT ON COLUMN rpt_pb_dict_value.SUB_ITEM_NAME IS '字典项名称';
COMMENT ON COLUMN rpt_pb_dict_value.SUB_ITEM IS '字典项号';
COMMENT ON COLUMN rpt_pb_dict_value.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_dict_value.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_dict_value.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_dict_value.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_dict_value.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_file_resource  (
  id NUMBER(20,0) NOT NULL,
  file_code varchar(256) NOT NULL,
  thumbnail_file_code varchar(256) NULL ,
  file_type varchar(8) NOT NULL,
  file_name varchar(64) NOT NULL,
  load_type varchar(8) NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (id)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_file_resource IS '文件资源表';
COMMENT ON COLUMN rpt_pb_file_resource.id IS '主键id';
COMMENT ON COLUMN rpt_pb_file_resource.file_code IS '文件地址编码';
COMMENT ON COLUMN rpt_pb_file_resource.thumbnail_file_code IS '缩略图文件base64';
COMMENT ON COLUMN rpt_pb_file_resource.file_type IS '资源类型';
COMMENT ON COLUMN rpt_pb_file_resource.file_name IS '资源名称';
COMMENT ON COLUMN rpt_pb_file_resource.load_type IS '文件加载类型';
COMMENT ON COLUMN rpt_pb_file_resource.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_file_resource.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_file_resource.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_file_resource.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_file_resource.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_screen  (
  SCREEN_ID NUMBER(20,0) NOT NULL,
  SCREEN_NAME varchar(128) NOT NULL,
  CLASS_ID NUMBER(20,0) NOT NULL,
  INTRODUCTION varchar(1024) NULL ,
  ABBR_IMG_ADDR varchar(256) NULL ,
  small_ABBR_IMG_ADDR varchar(256) NULL ,
  BASE_PROP CLOB NOT NULL,
  status varchar(8) DEFAULT '0' NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (SCREEN_ID)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_screen IS '大屏定义表';
COMMENT ON COLUMN rpt_pb_screen.SCREEN_ID IS '大屏编号';
COMMENT ON COLUMN rpt_pb_screen.SCREEN_NAME IS '大屏名称';
COMMENT ON COLUMN rpt_pb_screen.CLASS_ID IS '分类编号';
COMMENT ON COLUMN rpt_pb_screen.INTRODUCTION IS '简介';
COMMENT ON COLUMN rpt_pb_screen.ABBR_IMG_ADDR IS '缩略图地址';
COMMENT ON COLUMN rpt_pb_screen.small_ABBR_IMG_ADDR IS '小缩略图base64';
COMMENT ON COLUMN rpt_pb_screen.BASE_PROP IS '基本属性';
COMMENT ON COLUMN rpt_pb_screen.status IS '大屏状态';
COMMENT ON COLUMN rpt_pb_screen.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_screen.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_screen.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_screen.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_screen.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_screen_class  (
  CLASS_ID NUMBER(20,0) NOT NULL,
  PARENT_CLASS_ID NUMBER(20,0) NOT NULL,
  CLASS_NAME varchar(256) NOT NULL,
  class_order NUMBER(20,0) DEFAULT 0 NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (CLASS_ID)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_screen_class IS '大屏分类定义表';
COMMENT ON COLUMN rpt_pb_screen_class.CLASS_ID IS '分类编号';
COMMENT ON COLUMN rpt_pb_screen_class.PARENT_CLASS_ID IS '父类编号';
COMMENT ON COLUMN rpt_pb_screen_class.CLASS_NAME IS '分类名称';
COMMENT ON COLUMN rpt_pb_screen_class.class_order IS '分组排序序号';
COMMENT ON COLUMN rpt_pb_screen_class.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_screen_class.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_screen_class.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_screen_class.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_screen_class.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_screen_element  (
  ID NUMBER(20,0) NOT NULL,
  SCREEN_ID NUMBER(20,0) NOT NULL,
  ELEMENT_ID varchar(128) NOT NULL,
  COMPONENT_ID NUMBER(20,0) NOT NULL,
  DATA_SET_ID NUMBER(20,0) NULL ,
  ELEMENT_LAYOUT_PROP CLOB NOT NULL,
  ELEMENT_BASE_PROP CLOB NOT NULL,
  ELEMENT_DATA_PROP CLOB NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (ID)
)
NOCOMPRESS
NOPARALLEL ;
CREATE UNIQUE INDEX PB_SCREEN_ELEMENT_INDEX ON rpt_pb_screen_element (SCREEN_ID, ELEMENT_ID);
COMMENT ON TABLE rpt_pb_screen_element IS '数据映射字典项表';
COMMENT ON COLUMN rpt_pb_screen_element.ID IS 'ID';
COMMENT ON COLUMN rpt_pb_screen_element.SCREEN_ID IS '大屏编号';
COMMENT ON COLUMN rpt_pb_screen_element.ELEMENT_ID IS '元素编号';
COMMENT ON COLUMN rpt_pb_screen_element.COMPONENT_ID IS '组件编号';
COMMENT ON COLUMN rpt_pb_screen_element.DATA_SET_ID IS '数据集编号';
COMMENT ON COLUMN rpt_pb_screen_element.ELEMENT_LAYOUT_PROP IS '元素布局属性';
COMMENT ON COLUMN rpt_pb_screen_element.ELEMENT_BASE_PROP IS '元素基本属性';
COMMENT ON COLUMN rpt_pb_screen_element.ELEMENT_DATA_PROP IS '元素数据属性';
COMMENT ON COLUMN rpt_pb_screen_element.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_screen_element.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_screen_element.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_screen_element.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_screen_element.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_screen_file  (
  id NUMBER(20,0) NOT NULL,
  screen_id NUMBER(20,0) NOT NULL,
  element_id varchar(256) NOT NULL,
  file_id NUMBER(20,0) NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (id)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_screen_file IS '大屏文件表';
COMMENT ON COLUMN rpt_pb_screen_file.id IS '主键id';
COMMENT ON COLUMN rpt_pb_screen_file.screen_id IS '大屏代码';
COMMENT ON COLUMN rpt_pb_screen_file.element_id IS '元素编号';
COMMENT ON COLUMN rpt_pb_screen_file.file_id IS '文件编号';
COMMENT ON COLUMN rpt_pb_screen_file.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_screen_file.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_screen_file.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_screen_file.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_screen_file.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_screen_tmp  (
  TEMPLATE_ID NUMBER(20,0) NOT NULL,
  TEMPLATE_NAME varchar(128) NOT NULL,
  INTRODUCTION varchar(1024) NULL ,
  ABBR_IMG_ADDR varchar(256) NULL ,
  small_ABBR_IMG_ADDR varchar(256) NULL ,
  BASE_PROP CLOB NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (TEMPLATE_ID)
)
NOCOMPRESS
NOPARALLEL ;
COMMENT ON TABLE rpt_pb_screen_tmp IS '大屏模板表';
COMMENT ON COLUMN rpt_pb_screen_tmp.TEMPLATE_ID IS '模板编号';
COMMENT ON COLUMN rpt_pb_screen_tmp.TEMPLATE_NAME IS '模板名称';
COMMENT ON COLUMN rpt_pb_screen_tmp.INTRODUCTION IS '简介';
COMMENT ON COLUMN rpt_pb_screen_tmp.ABBR_IMG_ADDR IS '缩略图地址';
COMMENT ON COLUMN rpt_pb_screen_tmp.small_ABBR_IMG_ADDR IS '小缩略图地址';
COMMENT ON COLUMN rpt_pb_screen_tmp.BASE_PROP IS '基本属性';
COMMENT ON COLUMN rpt_pb_screen_tmp.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_screen_tmp.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_screen_tmp.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_screen_tmp.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_screen_tmp.UPDATEDATE IS '修改时间';

CREATE TABLE rpt_pb_screen_tmp_element  (
  ID NUMBER(20,0) NOT NULL,
  TEMPLATE_ID NUMBER(20,0) NOT NULL,
  ELEMENT_ID varchar(128) NOT NULL,
  DATA_SET_ID NUMBER(20,0) NULL ,
  COMPONENT_ID NUMBER(20,0) NOT NULL,
  ELEMENT_LAYOUT_PROP CLOB NOT NULL,
  ELEMENT_BASE_PROP CLOB NOT NULL,
  ELEMENT_DATA_PROP CLOB NOT NULL,
  DATAID NUMBER(20,0) NULL ,
  CREATEBY varchar(256) NULL ,
  CREATEDATE NUMBER(20,0) NULL ,
  UPDATEBY varchar(256) NULL ,
  UPDATEDATE NUMBER(20,0) NULL ,
  PRIMARY KEY (ID)
)
NOCOMPRESS
NOPARALLEL ;
CREATE UNIQUE INDEX PB_SCREEN_TMP_ELEMENT_INDEX ON rpt_pb_screen_tmp_element (TEMPLATE_ID, ELEMENT_ID);
COMMENT ON TABLE rpt_pb_screen_tmp_element IS '大屏模板元素表';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.ID IS 'ID';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.TEMPLATE_ID IS '模板编号';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.ELEMENT_ID IS '元素编号';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.DATA_SET_ID IS '数据集编号';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.COMPONENT_ID IS '组件编号';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.ELEMENT_LAYOUT_PROP IS '元素布局属性';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.ELEMENT_BASE_PROP IS '元素基本属性';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.ELEMENT_DATA_PROP IS '元素数据属性';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.DATAID IS 'DATAID';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.CREATEBY IS '创建人';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.CREATEDATE IS '创建时间';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.UPDATEBY IS '修改人';
COMMENT ON COLUMN rpt_pb_screen_tmp_element.UPDATEDATE IS '修改时间';
