﻿-- 
--  creating table koca_org_info_base
--  ============================
-- 
create table koca_org_info_base
(
  org_code      varchar(8) not null,
  org_status    varchar(2),
  org_type      varchar(8),
  parent_org    varchar(8),
  org_name      varchar(32),
  org_full_name varchar(64),
  address       varchar(64),
  zip_code      varchar(6),
  tel           varchar(16),
  remark        varchar(128)
)
;
comment on column koca_org_info_base.org_code
  is '机构代码';
comment on column koca_org_info_base.org_status
  is '机构状态，字典，org_status';
comment on column koca_org_info_base.org_type
  is '机构类型，字典，org_type';
comment on column koca_org_info_base.parent_org
  is '上级机构';
comment on column koca_org_info_base.org_name
  is '机构名称';
comment on column koca_org_info_base.org_full_name
  is '机构全称';
comment on column koca_org_info_base.address
  is '机构地址';
comment on column koca_org_info_base.zip_code
  is '机构邮编';
comment on column koca_org_info_base.tel
  is '机构电话';
comment on column koca_org_info_base.remark
  is '备注信息';
alter table koca_org_info_base
  add primary key (org_code);

-- 
--  creating table koca_org_info_ext
--  ===========================
-- 
create table koca_org_info_ext
(
  org_code  varchar(8) not null,
  org_key   varchar(16),
  org_value varchar(128)
)
;
comment on column koca_org_info_ext.org_code
  is '机构代码，主键';
comment on column koca_org_info_ext.org_key
  is '信息key，字典，org_key';
comment on column koca_org_info_ext.org_value
  is '信息value';
alter table koca_org_info_ext
  add constraint org_info_ext_key primary key (org_code);

-- 
--  creating table koca_role_info
--  ========================
-- 
create table koca_role_info
(
  role_no     varchar(8) not null,
  role_name   varchar(32),
  role_type   varchar(2),
  role_status varchar(2),
  remark      varchar(128),
  tenant_id   varchar(32) default '*',
  modifiable   varchar(2) default '1'
)
;
comment on table koca_role_info
  is '角色信息表';
comment on column koca_role_info.role_no
  is '角色编号';
comment on column koca_role_info.role_name
  is '角色名称';
comment on column koca_role_info.role_type
  is '角色类型';
comment on column koca_role_info.role_status
  is '角色状态';
comment on column koca_role_info.remark
  is '描述';
comment on column koca_role_info.tenant_id
    is '租户id';
comment on column koca_role_info.modifiable
    is '1 可删除 0，不可删除';
alter table koca_role_info
  add primary key (role_no, tenant_id);

-- 
--  creating table koca_user_info_base
--  =============================
-- 
create table koca_user_info_base
(
  user_no       varchar(32) not null,
  user_type     varchar(2) not null,
  user_status   varchar(2) not null,
  user_code     varchar(32) not null,
  user_name     varchar(32) not null,
  id_type       varchar(2) not null,
  id_code       varchar(32) not null,
  id_iss_agcy   varchar(64),
  id_address    varchar(128),
  id_begin_date varchar(8),
  id_exp_date   varchar(8),
  birthday      varchar(8),
  sex           varchar(2),
  nationality   varchar(2),
  citizenship   varchar(3),
  education     varchar(2),
  native_place  varchar(32),
  mobile_tel    varchar(11),
  email         varchar(32),
  address       varchar(128),
  zip_code      varchar(6),
  user_icon     varchar(255),
  create_date   varchar(8),
  cancel_date   varchar(32),
  remark        varchar(128),
  oper_ext_attr varchar(16) default '0'
)
;
comment on column koca_user_info_base.user_no
  is '人员编号';
comment on column koca_user_info_base.user_type
  is '人员类型，字典user_type';
comment on column koca_user_info_base.user_status
  is '人员状态,字典user_status';
comment on column koca_user_info_base.user_code
  is '人员代码';
comment on column koca_user_info_base.user_name
  is '姓名';
comment on column koca_user_info_base.id_type
  is '证件类型';
comment on column koca_user_info_base.id_code
  is '证件号码';
comment on column koca_user_info_base.id_iss_agcy
  is '发证机关';
comment on column koca_user_info_base.id_address
  is '证件地址';
comment on column koca_user_info_base.id_begin_date
  is '证件开始日期';
comment on column koca_user_info_base.id_exp_date
  is '证件结束日期';
comment on column koca_user_info_base.birthday
  is '出生日期';
comment on column koca_user_info_base.sex
  is '性别,字典，sex';
comment on column koca_user_info_base.nationality
  is '民族,字典';
comment on column koca_user_info_base.citizenship
  is '国籍,字典';
comment on column koca_user_info_base.education
  is '学历，字典';
comment on column koca_user_info_base.native_place
  is '籍贯';
comment on column koca_user_info_base.mobile_tel
  is '手机号码';
comment on column koca_user_info_base.email
  is '邮箱';
comment on column koca_user_info_base.address
  is '联系地址';
comment on column koca_user_info_base.zip_code
  is '邮政编码';
comment on column koca_user_info_base.user_icon
  is '用户头像';
comment on column koca_user_info_base.create_date
  is '注册日期';
comment on column koca_user_info_base.cancel_date
  is '注销日期';
comment on column koca_user_info_base.remark
  is '备注信息';
alter table koca_user_info_base
  add primary key (user_no);

-- 
--  creating table koca_user_info_ext
--  ============================
-- 
create table koca_user_info_ext
(
  user_no    varchar(32) not null,
  user_key   varchar(16) not null,
  user_value varchar(128)
)
;
comment on column koca_user_info_ext.user_no
  is '人员编号';
comment on column koca_user_info_ext.user_key
  is '信息key，字典user_key';
comment on column koca_user_info_ext.user_value
  is '信息value';
alter table koca_user_info_ext
  add constraint user_info_ext_key primary key (user_no, user_key);

-- 
--  creating table koca_user_opt_log
--  ===========================
-- 
create table koca_user_opt_log
(
  s_no        numeric not null,
  begin_time  timestamp ,
  end_time    timestamp,
  user_no     varchar(32),
  opt_code    varchar(64),
  opt_data    text,
  res_status  varchar(8),
  res_message varchar(128),
  res_code    varchar(8),
  remark      varchar(128)
)
;
comment on column koca_user_opt_log.s_no
  is '自增';
alter table koca_user_opt_log
  add primary key (s_no);

-- 
--  creating table koca_user_org_info
--  ============================
-- 
create table koca_user_org_info
(
  org_code varchar(8) not null,
  user_no  varchar(32) not null
)
;
comment on column koca_user_org_info.org_code
  is '机构代码，主键';
alter table koca_user_org_info
  add constraint user_koca_org_info_key primary key (user_no);

-- 
--  creating table koca_user_pwd
--  =======================
-- 
create table koca_user_pwd
(
  user_no     varchar(32) not null,
  pwd         varchar(64),
  pwd_status  varchar(2),
  update_time timestamp,
  remark      varchar(128),
  wrong_time numeric(8) default 0
)
;
alter table koca_user_pwd
  add primary key (user_no);

-- 
--  creating table koca_user_pwd_log
--  ===========================
-- 
create table koca_user_pwd_log
(
  sno      numeric(11) not null,
  user_no  varchar(32),
  pwd      varchar(64),
  modified_oper      varchar(64),
  set_date timestamp
)
;
alter table koca_user_pwd_log
  add primary key (sno);

-- 
--  creating table user_koca_role_info
--  =============================
-- 
create table koca_user_role_info
(
  user_no varchar(32) not null,
  role_no varchar(8) not null,
  tenant_id  varchar(32) not null
)
;
comment on table koca_user_role_info
  is '人员角色信息表';
comment on column koca_user_role_info.user_no
  is '人员编号';
comment on column koca_user_role_info.role_no
  is '角色编号';
alter table koca_user_role_info
  add constraint user_role_key primary key (user_no, role_no, tenant_id);

-- 
--  creating table koca_menu_api
--  =============================
-- 
create table koca_menu_api
(
  menu_id varchar(10) not null,
  api_code varchar(100) not null,
  resource_url varchar(255)
)
;
comment on table koca_menu_api
  is '菜单api信息表';
comment on column koca_menu_api.menu_id
  is '菜单编号';
comment on column koca_menu_api.api_code
  is 'api接口代码';
  comment on column koca_menu_api.resource_url
  is '请求resource路径';
alter table koca_menu_api
  add constraint menu_api_key primary key (api_code);

create table koca_sys_password_parameter
(
  par_code      varchar(32) not null,
  par_name      varchar(128),
  par_val  varchar(32),
  remark        varchar(128)
);
alter table koca_sys_password_parameter
  add primary key (par_code);
